'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var core = require('@vue-storefront/core');
var compositionApi = require('@nuxtjs/composition-api');

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
}

var ROOT_COLLECTION = '__root_collection__';
var BILLING_TYPE = 'billing';
var ITEMS_PER_PAGE = [20, 40, 100];

var createPrice = function (price) {
    return price ? price / 100 : 0;
};
var setWishlist = function (wishlist) {
    localStorage.setItem('wishlist', JSON.stringify(wishlist));
    return '';
};
var getWishlist = function () {
    if (!localStorage.getItem('wishlist') || localStorage.getItem('wishlist') === '1') {
        setWishlist([]);
    }
    return JSON.parse(localStorage.getItem('wishlist'));
};

// Return types from Vendure mutations on Cart (Order) are unions of Order and something else (i.e. OrderModificationError).
// When we return this union type, TypeScript complains that there are no properties in common with order as it returns only __typename.
// So, in all mutations we have a return type of Promise<Order> and we are also casting the output i.e:
// return response?.data?.X as Order
var params$9 = {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    load: function (context, _a) {
        var customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.getCart(customQuery)];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.activeOrder];
                }
            });
        });
    },
    // TODO: update to use currentCart
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    addItem: function (context, _a) {
        _a.currentCart; var product = _a.product, quantity = _a.quantity, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var productVariantId, response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0:
                        productVariantId = (product === null || product === void 0 ? void 0 : product._variantId) || (product === null || product === void 0 ? void 0 : product._id);
                        return [4 /*yield*/, context.$vendure.api.addToCart({ productVariantId: productVariantId, quantity: quantity }, customQuery)];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.addItemToOrder];
                }
            });
        });
    },
    // TODO: update to use currentCart
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    removeItem: function (context, _a) {
        _a.currentCart; var product = _a.product, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.removeFromCart({ orderLineId: product.id }, customQuery)];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.removeOrderLine];
                }
            });
        });
    },
    // TODO: update to use currentCart
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    updateItemQty: function (context, _a) {
        _a.currentCart; var product = _a.product, quantity = _a.quantity, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.updateCartQuantity({ orderLineId: product.id, quantity: quantity }, customQuery)];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.adjustOrderLine];
                }
            });
        });
    },
    // Not used in VSF for now
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    clear: function (context, _a) {
        _a.currentCart;
        return __awaiter(void 0, void 0, void 0, function () {
            return __generator(this, function (_b) {
                console.log('Mocked: useCart.clear');
                return [2 /*return*/, Promise.resolve({})];
            });
        });
    },
    // TODO: update to use currentCart
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    applyCoupon: function (context, _a) {
        var currentCart = _a.currentCart, couponCode = _a.couponCode, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b, _c, _d;
            return __generator(this, function (_e) {
                switch (_e.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.applyCartCoupon({ couponCode: couponCode }, customQuery)];
                    case 1:
                        response = _e.sent();
                        if ((_c = (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.applyCouponCode) === null || _c === void 0 ? void 0 : _c.errorCode) {
                            return [2 /*return*/, {
                                    updatedCart: currentCart
                                }];
                        }
                        return [2 /*return*/, {
                                updatedCart: (_d = response === null || response === void 0 ? void 0 : response.data) === null || _d === void 0 ? void 0 : _d.applyCouponCode,
                                updatedCoupon: couponCode
                            }];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    removeCoupon: function (context, _a) {
        var couponCode = _a.couponCode, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.removeCartCoupon({ couponCode: couponCode }, customQuery)];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, {
                                updatedCart: (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.removeCouponCode
                            }];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    isInCart: function (context, _a) {
        var _b;
        var currentCart = _a.currentCart, product = _a.product;
        return Boolean((_b = currentCart === null || currentCart === void 0 ? void 0 : currentCart.lines) === null || _b === void 0 ? void 0 : _b.find(function (orderLine) { var _a, _b; return ((_a = orderLine === null || orderLine === void 0 ? void 0 : orderLine.productVariant) === null || _a === void 0 ? void 0 : _a.id) === product._id || ((_b = orderLine === null || orderLine === void 0 ? void 0 : orderLine.productVariant) === null || _b === void 0 ? void 0 : _b.id) === product._variantId; }));
    }
};
var useCart = core.useCartFactory(params$9);

var params$8 = {
    provide: function () {
        return {
            cart: useCart()
        };
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    load: function (context, _a) {
        var customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var _b, _c, _d;
            return __generator(this, function (_e) {
                switch (_e.label) {
                    case 0:
                        if (!!((_d = (_c = (_b = context.cart) === null || _b === void 0 ? void 0 : _b.cart) === null || _c === void 0 ? void 0 : _c.value) === null || _d === void 0 ? void 0 : _d.billingAddress)) return [3 /*break*/, 2];
                        return [4 /*yield*/, context.cart.load({ customQuery: customQuery })];
                    case 1:
                        _e.sent();
                        _e.label = 2;
                    case 2: return [2 /*return*/, context.cart.cart.value.billingAddress];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    save: function (context, _a) {
        _a.params; var billingDetails = _a.billingDetails, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b, _c;
            return __generator(this, function (_d) {
                switch (_d.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.updateAddressDetails({ input: billingDetails, type: BILLING_TYPE }, customQuery)];
                    case 1:
                        response = _d.sent();
                        return [2 /*return*/, (_c = (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.setOrderBillingAddress) === null || _c === void 0 ? void 0 : _c.billingAddress];
                }
            });
        });
    }
};
var useBilling = core.useBillingFactory(params$8);

function useCategoryFactory(factoryParams) {
    return function useCategory(id) {
        var _this = this;
        var categories = core.sharedRef({}, "useCategory-categories-" + id);
        var loading = core.sharedRef(false, "useCategory-loading-" + id);
        var error = core.sharedRef({
            search: null
        }, "useCategory-error-" + id);
        var _factoryParams = core.configureFactoryParams(factoryParams);
        var search = function (searchParams) { return __awaiter(_this, void 0, void 0, function () {
            var _a, err_1;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        core.Logger.debug("useCategory/" + id + "/search", searchParams);
                        _b.label = 1;
                    case 1:
                        _b.trys.push([1, 3, 4, 5]);
                        loading.value = true;
                        _a = categories;
                        return [4 /*yield*/, _factoryParams.categorySearch(searchParams)];
                    case 2:
                        _a.value = _b.sent();
                        error.value.search = null;
                        return [3 /*break*/, 5];
                    case 3:
                        err_1 = _b.sent();
                        error.value.search = err_1;
                        core.Logger.error("useCategory/" + id + "/search", err_1);
                        return [3 /*break*/, 5];
                    case 4:
                        loading.value = false;
                        return [7 /*endfinally*/];
                    case 5: return [2 /*return*/];
                }
            });
        }); };
        return {
            search: search,
            loading: compositionApi.computed(function () { return loading.value; }),
            categories: compositionApi.computed(function () { return categories.value; }),
            error: compositionApi.computed(function () { return error.value; })
        };
    };
}

var useUserFactory = function (factoryParams) {
    return function useUser() {
        var _this = this;
        var errorsFactory = function () { return ({
            updateUser: null,
            register: null,
            login: null,
            logout: null,
            changePassword: null,
            load: null,
            updateEmail: null
        }); };
        var user = core.sharedRef(null, 'useUser-user');
        var loading = core.sharedRef(false, 'useUser-loading');
        var isAuthenticated = compositionApi.computed(function () { return Boolean(user.value); });
        var error = core.sharedRef(errorsFactory(), 'useUser-error');
        var _factoryParams = core.configureFactoryParams(factoryParams);
        var setUser = function (newUser) {
            user.value = newUser;
            core.Logger.debug('useUserFactory.setUser', newUser);
        };
        var resetErrorValue = function () {
            error.value = errorsFactory();
        };
        var updateUser = function (_a) {
            var providedUser = _a.user, customQuery = _a.customQuery;
            return __awaiter(_this, void 0, void 0, function () {
                var _b, err_1;
                return __generator(this, function (_c) {
                    switch (_c.label) {
                        case 0:
                            core.Logger.debug('useUserFactory.updateUser', providedUser);
                            resetErrorValue();
                            _c.label = 1;
                        case 1:
                            _c.trys.push([1, 3, 4, 5]);
                            loading.value = true;
                            _b = user;
                            return [4 /*yield*/, _factoryParams.updateUser({ currentUser: user.value, updatedUserData: providedUser, customQuery: customQuery })];
                        case 2:
                            _b.value = _c.sent();
                            error.value.updateUser = null;
                            return [3 /*break*/, 5];
                        case 3:
                            err_1 = _c.sent();
                            error.value.updateUser = err_1;
                            core.Logger.error('useUser/updateUser', err_1);
                            return [3 /*break*/, 5];
                        case 4:
                            loading.value = false;
                            return [7 /*endfinally*/];
                        case 5: return [2 /*return*/];
                    }
                });
            });
        };
        var register = function (_a) {
            var providedUser = _a.user, customQuery = _a.customQuery;
            return __awaiter(_this, void 0, void 0, function () {
                var err_2;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            core.Logger.debug('useUserFactory.register', providedUser);
                            resetErrorValue();
                            _b.label = 1;
                        case 1:
                            _b.trys.push([1, 3, 4, 5]);
                            loading.value = true;
                            // In Vendure the register will return boolean instead of customer so we cannot save it as user.
                            return [4 /*yield*/, _factoryParams.register(__assign(__assign({}, providedUser), { customQuery: customQuery }))];
                        case 2:
                            // In Vendure the register will return boolean instead of customer so we cannot save it as user.
                            _b.sent();
                            error.value.register = null;
                            return [3 /*break*/, 5];
                        case 3:
                            err_2 = _b.sent();
                            error.value.register = err_2;
                            core.Logger.error('useUser/register', err_2);
                            return [3 /*break*/, 5];
                        case 4:
                            loading.value = false;
                            return [7 /*endfinally*/];
                        case 5: return [2 /*return*/];
                    }
                });
            });
        };
        var login = function (_a) {
            var providedUser = _a.user, customQuery = _a.customQuery;
            return __awaiter(_this, void 0, void 0, function () {
                var _b, err_3;
                return __generator(this, function (_c) {
                    switch (_c.label) {
                        case 0:
                            core.Logger.debug('useUserFactory.login', providedUser);
                            resetErrorValue();
                            _c.label = 1;
                        case 1:
                            _c.trys.push([1, 3, 4, 5]);
                            loading.value = true;
                            _b = user;
                            return [4 /*yield*/, _factoryParams.logIn(__assign(__assign({}, providedUser), { customQuery: customQuery }))];
                        case 2:
                            _b.value = _c.sent();
                            error.value.login = null;
                            return [3 /*break*/, 5];
                        case 3:
                            err_3 = _c.sent();
                            error.value.login = err_3;
                            core.Logger.error('useUser/login', err_3);
                            return [3 /*break*/, 5];
                        case 4:
                            loading.value = false;
                            return [7 /*endfinally*/];
                        case 5: return [2 /*return*/];
                    }
                });
            });
        };
        var logout = function () { return __awaiter(_this, void 0, void 0, function () {
            var err_4;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        core.Logger.debug('useUserFactory.logout');
                        resetErrorValue();
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        return [4 /*yield*/, _factoryParams.logOut({ currentUser: user.value })];
                    case 2:
                        _a.sent();
                        error.value.logout = null;
                        user.value = null;
                        return [3 /*break*/, 4];
                    case 3:
                        err_4 = _a.sent();
                        error.value.logout = err_4;
                        core.Logger.error('useUser/logout', err_4);
                        return [3 /*break*/, 4];
                    case 4: return [2 /*return*/];
                }
            });
        }); };
        var changePassword = function (params) { return __awaiter(_this, void 0, void 0, function () {
            var _a, err_5;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        core.Logger.debug('useUserFactory.changePassword', { currentPassword: core.mask(params.current), newPassword: core.mask(params.new) });
                        resetErrorValue();
                        _b.label = 1;
                    case 1:
                        _b.trys.push([1, 3, 4, 5]);
                        loading.value = true;
                        _a = user;
                        return [4 /*yield*/, _factoryParams.changePassword({
                                currentUser: user.value,
                                currentPassword: params.currentPassword,
                                newPassword: params.newPassword,
                                customQuery: params.customQuery
                            })];
                    case 2:
                        _a.value = _b.sent();
                        error.value.changePassword = null;
                        return [3 /*break*/, 5];
                    case 3:
                        err_5 = _b.sent();
                        error.value.changePassword = err_5;
                        core.Logger.error('useUser/changePassword', err_5);
                        return [3 /*break*/, 5];
                    case 4:
                        loading.value = false;
                        return [7 /*endfinally*/];
                    case 5: return [2 /*return*/];
                }
            });
        }); };
        var load = function (_a) {
            var _b = _a === void 0 ? { customQuery: undefined } : _a, customQuery = _b.customQuery;
            return __awaiter(_this, void 0, void 0, function () {
                var _c, err_6;
                return __generator(this, function (_d) {
                    switch (_d.label) {
                        case 0:
                            core.Logger.debug('useUserFactory.load');
                            resetErrorValue();
                            _d.label = 1;
                        case 1:
                            _d.trys.push([1, 3, 4, 5]);
                            loading.value = true;
                            _c = user;
                            return [4 /*yield*/, _factoryParams.load({ customQuery: customQuery })];
                        case 2:
                            _c.value = _d.sent();
                            error.value.load = null;
                            return [3 /*break*/, 5];
                        case 3:
                            err_6 = _d.sent();
                            error.value.load = err_6;
                            core.Logger.error('useUser/load', err_6);
                            return [3 /*break*/, 5];
                        case 4:
                            loading.value = false;
                            return [7 /*endfinally*/];
                        case 5: return [2 /*return*/];
                    }
                });
            });
        };
        var updateEmail = function (_a) {
            var providedUser = _a.user, customQuery = _a.customQuery, password = _a.password, newEmail = _a.newEmail;
            return __awaiter(_this, void 0, void 0, function () {
                var err_7;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            core.Logger.debug('useUserFactory.updateEmail', providedUser);
                            resetErrorValue();
                            _b.label = 1;
                        case 1:
                            _b.trys.push([1, 3, 4, 5]);
                            loading.value = true;
                            return [4 /*yield*/, _factoryParams.updateEmail({ currentUser: user.value, updatedUserData: providedUser, password: password, newEmail: newEmail, customQuery: customQuery })];
                        case 2:
                            _b.sent();
                            error.value.updateEmail = null;
                            return [3 /*break*/, 5];
                        case 3:
                            err_7 = _b.sent();
                            error.value.updateEmail = err_7;
                            core.Logger.error('useUser/updateEmail', err_7);
                            return [3 /*break*/, 5];
                        case 4:
                            loading.value = false;
                            return [7 /*endfinally*/];
                        case 5: return [2 /*return*/];
                    }
                });
            });
        };
        return {
            setUser: setUser,
            user: compositionApi.computed(function () { return user.value; }),
            updateUser: updateUser,
            register: register,
            login: login,
            logout: logout,
            isAuthenticated: isAuthenticated,
            changePassword: changePassword,
            updateEmail: updateEmail,
            load: load,
            loading: compositionApi.computed(function () { return loading.value; }),
            error: compositionApi.computed(function () { return error.value; })
        };
    };
};

function usePaymentFactory(factoryParams) {
    return function usePayment() {
        var _this = this;
        var methods = core.sharedRef([], 'usePayment-methods');
        var loading = core.sharedRef(false, 'usePayment-loading');
        var error = core.sharedRef({
            set: null,
            load: null
        }, 'usePayment-error');
        var _factoryParams = core.configureFactoryParams(factoryParams);
        var load = function (searchParams) { return __awaiter(_this, void 0, void 0, function () {
            var _a, err_1;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        core.Logger.debug('usePayment/load', searchParams);
                        _b.label = 1;
                    case 1:
                        _b.trys.push([1, 3, 4, 5]);
                        loading.value = true;
                        _a = methods;
                        return [4 /*yield*/, _factoryParams.load(searchParams)];
                    case 2:
                        _a.value = _b.sent();
                        error.value.load = null;
                        return [3 /*break*/, 5];
                    case 3:
                        err_1 = _b.sent();
                        error.value.load = err_1;
                        core.Logger.error('usePayment/load', err_1);
                        return [3 /*break*/, 5];
                    case 4:
                        loading.value = false;
                        return [7 /*endfinally*/];
                    case 5: return [2 /*return*/];
                }
            });
        }); };
        var set = function (searchParams) { return __awaiter(_this, void 0, void 0, function () {
            var selectedMethod, err_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        core.Logger.debug('usePayment/set', searchParams);
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, 4, 5]);
                        loading.value = true;
                        return [4 /*yield*/, _factoryParams.set(searchParams)];
                    case 2:
                        selectedMethod = _a.sent();
                        error.value.set = null;
                        return [2 /*return*/, selectedMethod];
                    case 3:
                        err_2 = _a.sent();
                        error.value.set = err_2;
                        core.Logger.error('usePayment/set', err_2);
                        return [3 /*break*/, 5];
                    case 4:
                        loading.value = false;
                        return [7 /*endfinally*/];
                    case 5: return [2 /*return*/];
                }
            });
        }); };
        return {
            set: set,
            load: load,
            loading: compositionApi.computed(function () { return loading.value; }),
            methods: compositionApi.computed(function () { return methods.value; }),
            error: compositionApi.computed(function () { return error.value; })
        };
    };
}

function useRelatedProductsFactory(factoryParams) {
    return function useRelatedProducts() {
        var _this = this;
        var relatedProducts = core.sharedRef([], 'useRelatedProducts-methods');
        var loading = core.sharedRef(false, 'useRelatedProducts-loading');
        var error = core.sharedRef({
            load: null
        }, 'useRelatedProducts-error');
        var _factoryParams = core.configureFactoryParams(factoryParams);
        var load = function (searchParams) { return __awaiter(_this, void 0, void 0, function () {
            var _a, err_1;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        core.Logger.debug('useRelatedProducts/load', searchParams);
                        _b.label = 1;
                    case 1:
                        _b.trys.push([1, 3, 4, 5]);
                        loading.value = true;
                        _a = relatedProducts;
                        return [4 /*yield*/, _factoryParams.load(searchParams)];
                    case 2:
                        _a.value = _b.sent();
                        error.value.load = null;
                        return [3 /*break*/, 5];
                    case 3:
                        err_1 = _b.sent();
                        error.value.load = err_1;
                        core.Logger.error('useRelatedProducts/load', err_1);
                        return [3 /*break*/, 5];
                    case 4:
                        loading.value = false;
                        return [7 /*endfinally*/];
                    case 5: return [2 /*return*/];
                }
            });
        }); };
        return {
            load: load,
            loading: compositionApi.computed(function () { return loading.value; }),
            relatedProducts: compositionApi.computed(function () { return relatedProducts.value; }),
            error: compositionApi.computed(function () { return error.value; })
        };
    };
}

var useCategoryFactoryParams = {
    categorySearch: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var categorySearchParams, categoryResponse;
        var _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    categorySearchParams = { options: __assign({}, params === null || params === void 0 ? void 0 : params.options) };
                    return [4 /*yield*/, context.$vendure.api.getCategory(categorySearchParams, params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    categoryResponse = _b.sent();
                    return [2 /*return*/, (_a = categoryResponse === null || categoryResponse === void 0 ? void 0 : categoryResponse.data) === null || _a === void 0 ? void 0 : _a.collections];
            }
        });
    }); }
};
var useCategory = useCategoryFactory(useCategoryFactoryParams);

function useContent() { }

var useFacetFactoryParams = {
    // TODO: Fix this with custom type/interface. In Vendure `sort: SearchResultSortParameter` while in VSF Core `sort: string`
    search: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var searchParams, searchResponse;
        var _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    searchParams = { input: __assign({}, params === null || params === void 0 ? void 0 : params.input) };
                    return [4 /*yield*/, context.$vendure.api.getFacet(searchParams, params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    searchResponse = _b.sent();
                    return [2 /*return*/, (_a = searchResponse === null || searchResponse === void 0 ? void 0 : searchResponse.data) === null || _a === void 0 ? void 0 : _a.search];
            }
        });
    }); }
};
var useFacet = core.useFacetFactory(useFacetFactoryParams);

// TODO: replace any with Order when working on order functionality
// import type { Order } from '@vue-storefront/vendure-api';
var factoryParams = {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    make: function (context, _a) {
        _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            return __generator(this, function (_b) {
                console.log('Mocked: useMakeOrder.make');
                return [2 /*return*/, {}];
            });
        });
    }
};
var useMakeOrder = core.useMakeOrderFactory(factoryParams);

var useProductFactoryParams = {
    productsSearch: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var customQuery, productSearchParams, productResponse;
        var _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    customQuery = params.customQuery, productSearchParams = __rest(params, ["customQuery"]);
                    return [4 /*yield*/, context.$vendure.api.getProduct(productSearchParams, customQuery)];
                case 1:
                    productResponse = _b.sent();
                    return [2 /*return*/, (_a = productResponse === null || productResponse === void 0 ? void 0 : productResponse.data) === null || _a === void 0 ? void 0 : _a.product];
            }
        });
    }); }
};
var useProduct = core.useProductFactory(useProductFactoryParams);

var params$7 = {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    searchReviews: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            console.log('Mocked: useReview.searchReviews');
            return [2 /*return*/, {}];
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    addReview: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            console.log('Mocked: useReview.addReview');
            return [2 /*return*/, {}];
        });
    }); }
};
var useReview = core.useReviewFactory(params$7);

var params$6 = {
    provide: function () {
        return {
            cart: useCart()
        };
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    load: function (context, _a) {
        var customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var _b, _c, _d;
            return __generator(this, function (_e) {
                switch (_e.label) {
                    case 0:
                        if (!!((_d = (_c = (_b = context.cart) === null || _b === void 0 ? void 0 : _b.cart) === null || _c === void 0 ? void 0 : _c.value) === null || _d === void 0 ? void 0 : _d.shippingAddress)) return [3 /*break*/, 2];
                        return [4 /*yield*/, context.cart.load({ customQuery: customQuery })];
                    case 1:
                        _e.sent();
                        _e.label = 2;
                    case 2: return [2 /*return*/, context.cart.cart.value.shippingAddress];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    save: function (context, _a) {
        var shippingDetails = _a.shippingDetails, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b, _c;
            return __generator(this, function (_d) {
                switch (_d.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.updateAddressDetails({ input: shippingDetails }, customQuery)];
                    case 1:
                        response = _d.sent();
                        return [2 /*return*/, (_c = (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.setOrderShippingAddress) === null || _c === void 0 ? void 0 : _c.shippingAddress];
                }
            });
        });
    }
};
var useShipping = core.useShippingFactory(params$6);

var params$5 = {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    load: function (context, _a) {
        var customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.getShippingMethods(customQuery)];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.eligibleShippingMethods];
                }
            });
        });
    },
    // Not used as Vendure provides a mutation that we are triggering from the theme via setShippingMethod API Client function
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    save: function (context, _a) {
        _a.shippingMethod; _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            return __generator(this, function (_b) {
                console.log('Mocked: saveShippingProvider');
                return [2 /*return*/, {}];
            });
        });
    }
};
var useShippingProvider = core.useShippingProviderFactory(params$5);

var params$4 = {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    load: function (context) { return __awaiter(void 0, void 0, void 0, function () {
        var response;
        var _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, context.$vendure.api.getActiveCustomer()];
                case 1:
                    response = _b.sent();
                    return [2 /*return*/, (_a = response === null || response === void 0 ? void 0 : response.data) === null || _a === void 0 ? void 0 : _a.activeCustomer];
            }
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    logOut: function (context) { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, context.$vendure.api.logout()];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    updateUser: function (context, _a) {
        _a.currentUser; var updatedUserData = _a.updatedUserData;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.updateCustomer({ firstName: updatedUserData.firstName, lastName: updatedUserData.lastName })];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.updateCustomer];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    register: function (context, _a) {
        var email = _a.email, password = _a.password, firstName = _a.firstName, lastName = _a.lastName;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.registerCustomerAccount({ emailAddress: email, password: password, firstName: firstName, lastName: lastName })];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.registerCustomerAccount];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    logIn: function (context, _a) {
        var username = _a.username, password = _a.password;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b, _c, _d;
            return __generator(this, function (_e) {
                switch (_e.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.login({ username: username, password: password })];
                    case 1:
                        response = _e.sent();
                        if (((_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.login).errorCode)
                            throw (_c = response === null || response === void 0 ? void 0 : response.data) === null || _c === void 0 ? void 0 : _c.login;
                        return [2 /*return*/, (_d = response === null || response === void 0 ? void 0 : response.data) === null || _d === void 0 ? void 0 : _d.login];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    changePassword: function (context, _a) {
        _a.currentUser; var currentPassword = _a.currentPassword, newPassword = _a.newPassword;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.updateCustomerPassword({ currentPassword: currentPassword, newPassword: newPassword })];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.updateCustomerPassword];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    updateEmail: function (context, _a) {
        _a.currentUser; _a.updatedUserData; var newEmail = _a.newEmail, password = _a.password;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.updateCustomerEmailAddress({ newEmail: newEmail, password: password })];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.updateCustomerEmailAddress];
                }
            });
        });
    }
};
var useUser = useUserFactory(params$4);

var params$3 = {
    provide: function () {
        return {
            user: useUser()
        };
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    addAddress: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var billingAddress, user;
        var _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    billingAddress = __assign({}, params === null || params === void 0 ? void 0 : params.address);
                    return [4 /*yield*/, context.$vendure.api.createCustomerAddress(billingAddress, params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, context.$vendure.api.getActiveCustomer()];
                case 2:
                    user = _c.sent();
                    return [2 /*return*/, (_b = (_a = user === null || user === void 0 ? void 0 : user.data) === null || _a === void 0 ? void 0 : _a.activeCustomer) === null || _b === void 0 ? void 0 : _b.addresses];
            }
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    deleteAddress: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var user;
        var _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0: return [4 /*yield*/, context.$vendure.api.deleteCustomerAddress(params === null || params === void 0 ? void 0 : params.address, params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, context.$vendure.api.getActiveCustomer()];
                case 2:
                    user = _c.sent();
                    return [2 /*return*/, (_b = (_a = user === null || user === void 0 ? void 0 : user.data) === null || _a === void 0 ? void 0 : _a.activeCustomer) === null || _b === void 0 ? void 0 : _b.addresses];
            }
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    updateAddress: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var billingAddress, user;
        var _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    billingAddress = __assign({}, params === null || params === void 0 ? void 0 : params.address);
                    return [4 /*yield*/, context.$vendure.api.updateCustomerAddress(billingAddress, params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, context.$vendure.api.getActiveCustomer()];
                case 2:
                    user = _c.sent();
                    return [2 /*return*/, (_b = (_a = user === null || user === void 0 ? void 0 : user.data) === null || _a === void 0 ? void 0 : _a.activeCustomer) === null || _b === void 0 ? void 0 : _b.addresses];
            }
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    load: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var _a, _b, _c;
        return __generator(this, function (_d) {
            return [2 /*return*/, (_c = (_b = (_a = context.user) === null || _a === void 0 ? void 0 : _a.user) === null || _b === void 0 ? void 0 : _b.value) === null || _c === void 0 ? void 0 : _c.addresses];
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    setDefaultAddress: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            console.log('Mocked: useUserBilling.setDefaultAddress');
            return [2 /*return*/, {}];
        });
    }); }
};
var useUserBilling = core.useUserBillingFactory(params$3);

var params$2 = {
    provide: function () {
        return {
            user: useUser()
        };
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    searchOrders: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var _a, _b, _c;
        return __generator(this, function (_d) {
            return [2 /*return*/, (_c = (_b = (_a = context.user) === null || _a === void 0 ? void 0 : _a.user) === null || _b === void 0 ? void 0 : _b.value) === null || _c === void 0 ? void 0 : _c.orders];
        });
    }); }
};
var useUserOrder = core.useUserOrderFactory(params$2);

var params$1 = {
    provide: function () {
        return {
            user: useUser()
        };
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    addAddress: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var shippingAddress, user;
        var _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    shippingAddress = __assign({}, params === null || params === void 0 ? void 0 : params.address);
                    return [4 /*yield*/, context.$vendure.api.createCustomerAddress(shippingAddress, params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, context.$vendure.api.getActiveCustomer()];
                case 2:
                    user = _c.sent();
                    return [2 /*return*/, (_b = (_a = user === null || user === void 0 ? void 0 : user.data) === null || _a === void 0 ? void 0 : _a.activeCustomer) === null || _b === void 0 ? void 0 : _b.addresses];
            }
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    deleteAddress: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var user;
        var _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0: return [4 /*yield*/, context.$vendure.api.deleteCustomerAddress(params === null || params === void 0 ? void 0 : params.address, params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, context.$vendure.api.getActiveCustomer()];
                case 2:
                    user = _c.sent();
                    return [2 /*return*/, (_b = (_a = user === null || user === void 0 ? void 0 : user.data) === null || _a === void 0 ? void 0 : _a.activeCustomer) === null || _b === void 0 ? void 0 : _b.addresses];
            }
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    updateAddress: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var shippingAddress, user;
        var _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    shippingAddress = __assign({}, params === null || params === void 0 ? void 0 : params.address);
                    return [4 /*yield*/, context.$vendure.api.updateCustomerAddress(shippingAddress, params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, context.$vendure.api.getActiveCustomer()];
                case 2:
                    user = _c.sent();
                    return [2 /*return*/, (_b = (_a = user === null || user === void 0 ? void 0 : user.data) === null || _a === void 0 ? void 0 : _a.activeCustomer) === null || _b === void 0 ? void 0 : _b.addresses];
            }
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    load: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var _a, _b, _c;
        return __generator(this, function (_d) {
            return [2 /*return*/, (_c = (_b = (_a = context.user) === null || _a === void 0 ? void 0 : _a.user) === null || _b === void 0 ? void 0 : _b.value) === null || _c === void 0 ? void 0 : _c.addresses];
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    setDefaultAddress: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            console.log('Mocked: useUserShipping.setDefaultAddress');
            return [2 /*return*/, {}];
        });
    }); }
};
var useUserShipping = core.useUserShippingFactory(params$1);

var params = {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    load: function (context) { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            if (process.client) {
                return [2 /*return*/, getWishlist() || []];
            }
            return [2 /*return*/];
        });
    }); },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    addItem: function (context, _a) {
        var product = _a.product;
        return __awaiter(void 0, void 0, void 0, function () {
            var wishlist;
            return __generator(this, function (_b) {
                wishlist = getWishlist();
                wishlist === null || wishlist === void 0 ? void 0 : wishlist.push(product);
                setWishlist(wishlist);
                return [2 /*return*/, wishlist];
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    removeItem: function (context, _a) {
        var product = _a.product;
        return __awaiter(void 0, void 0, void 0, function () {
            var wishlist, updatedWishlist;
            return __generator(this, function (_b) {
                wishlist = getWishlist();
                updatedWishlist = wishlist.filter(function (wishlistItem) { return wishlistItem.sku !== product.sku; });
                setWishlist(updatedWishlist);
                return [2 /*return*/, updatedWishlist];
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    clear: function (context, _a) {
        _a.currentWishlist;
        return __awaiter(void 0, void 0, void 0, function () {
            return __generator(this, function (_b) {
                if (process.client) {
                    setWishlist([]);
                }
                return [2 /*return*/, []];
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    isInWishlist: function (context, _a) {
        var product = _a.product;
        var wishlist = process.client ? getWishlist() : [];
        return Boolean(wishlist === null || wishlist === void 0 ? void 0 : wishlist.find(function (wishlistItem) {
            var equalSku = (wishlistItem === null || wishlistItem === void 0 ? void 0 : wishlistItem.sku) === (product === null || product === void 0 ? void 0 : product.sku);
            var equalId = (wishlistItem === null || wishlistItem === void 0 ? void 0 : wishlistItem._id) === (product === null || product === void 0 ? void 0 : product._id);
            var equalVariantId = (wishlistItem === null || wishlistItem === void 0 ? void 0 : wishlistItem._variantId) === (product === null || product === void 0 ? void 0 : product._variantId);
            return Boolean(equalSku && equalId && equalVariantId);
        }));
    }
};
var useWishlist = core.useWishlistFactory(params);

var useForgotPasswordFactoryParams = {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    resetPassword: function (context, _a) {
        var email = _a.email, currentResult = _a.currentResult, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var resetPasswordResult, err_1;
            var _b, _c, _d, _e, _f;
            return __generator(this, function (_g) {
                switch (_g.label) {
                    case 0:
                        _g.trys.push([0, 2, , 3]);
                        return [4 /*yield*/, context.$vendure.api.requestPasswordReset({ emailAddress: email }, customQuery)];
                    case 1:
                        resetPasswordResult = _g.sent();
                        return [2 /*return*/, __assign(__assign({}, currentResult), { resetPasswordResult: resetPasswordResult })];
                    case 2:
                        err_1 = _g.sent();
                        err_1.message = ((_c = (_b = err_1 === null || err_1 === void 0 ? void 0 : err_1.graphQLErrors) === null || _b === void 0 ? void 0 : _b[0]) === null || _c === void 0 ? void 0 : _c.message) || err_1.message;
                        throw ((_f = (_e = (_d = err_1 === null || err_1 === void 0 ? void 0 : err_1.response) === null || _d === void 0 ? void 0 : _d.data) === null || _e === void 0 ? void 0 : _e.graphQLErrors) === null || _f === void 0 ? void 0 : _f[0]) || err_1;
                    case 3: return [2 /*return*/];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    setNewPassword: function (context, _a) {
        var tokenValue = _a.tokenValue, newPassword = _a.newPassword, currentResult = _a.currentResult, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var setNewPasswordResult, err_2;
            var _b, _c, _d, _e, _f;
            return __generator(this, function (_g) {
                switch (_g.label) {
                    case 0:
                        _g.trys.push([0, 2, , 3]);
                        return [4 /*yield*/, context.$vendure.api.resetPassword({ tokenValue: tokenValue, newPassword: newPassword }, customQuery)];
                    case 1:
                        setNewPasswordResult = _g.sent();
                        return [2 /*return*/, __assign(__assign({}, currentResult), { setNewPasswordResult: setNewPasswordResult })];
                    case 2:
                        err_2 = _g.sent();
                        err_2.message = ((_c = (_b = err_2 === null || err_2 === void 0 ? void 0 : err_2.graphQLErrors) === null || _b === void 0 ? void 0 : _b[0]) === null || _c === void 0 ? void 0 : _c.message) || err_2.message;
                        throw ((_f = (_e = (_d = err_2 === null || err_2 === void 0 ? void 0 : err_2.response) === null || _d === void 0 ? void 0 : _d.data) === null || _e === void 0 ? void 0 : _e.graphQLErrors) === null || _f === void 0 ? void 0 : _f[0]) || err_2;
                    case 3: return [2 /*return*/];
                }
            });
        });
    }
};
var useForgotPassword = core.useForgotPasswordFactory(useForgotPasswordFactoryParams);

var usePaymentFactoryParams = {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    set: function (context, _a) {
        var method = _a.method, metadata = _a.metadata, customQuery = _a.customQuery;
        return __awaiter(void 0, void 0, void 0, function () {
            var response;
            var _b;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, context.$vendure.api.setPaymentMethod({ method: method, metadata: metadata }, customQuery)];
                    case 1:
                        response = _c.sent();
                        return [2 /*return*/, (_b = response === null || response === void 0 ? void 0 : response.data) === null || _b === void 0 ? void 0 : _b.addPaymentToOrder];
                }
            });
        });
    },
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    load: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var response;
        var _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, context.$vendure.api.getPaymentMethods(params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    response = _b.sent();
                    return [2 /*return*/, (_a = response === null || response === void 0 ? void 0 : response.data) === null || _a === void 0 ? void 0 : _a.eligiblePaymentMethods];
            }
        });
    }); }
};
var usePayment = usePaymentFactory(usePaymentFactoryParams);

var useRelatedProductsFactoryParams = {
    load: function (context, params) { return __awaiter(void 0, void 0, void 0, function () {
        var searchParams, searchResponse;
        var _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    searchParams = { input: __assign({}, params === null || params === void 0 ? void 0 : params.input) };
                    return [4 /*yield*/, context.$vendure.api.getRelatedProducts(searchParams, params === null || params === void 0 ? void 0 : params.customQuery)];
                case 1:
                    searchResponse = _b.sent();
                    return [2 /*return*/, (_a = searchResponse === null || searchResponse === void 0 ? void 0 : searchResponse.data) === null || _a === void 0 ? void 0 : _a.search];
            }
        });
    }); }
};
var useRelatedProducts = useRelatedProductsFactory(useRelatedProductsFactoryParams);

var getItems$3 = function (cart) {
    if (!(cart === null || cart === void 0 ? void 0 : cart.lines))
        return [];
    return cart === null || cart === void 0 ? void 0 : cart.lines;
};
var getItemName$2 = function (item) {
    var _a;
    return ((_a = item === null || item === void 0 ? void 0 : item.productVariant) === null || _a === void 0 ? void 0 : _a.name) || '';
};
var getItemImage$1 = function (item) {
    var _a;
    return ((_a = item === null || item === void 0 ? void 0 : item.featuredAsset) === null || _a === void 0 ? void 0 : _a.preview) || '';
};
var getItemPrice$2 = function (item) {
    return {
        regular: createPrice(item === null || item === void 0 ? void 0 : item.linePriceWithTax),
        special: createPrice(item === null || item === void 0 ? void 0 : item.discountedLinePrice)
    };
};
var getItemQty$2 = function (item) {
    return (item === null || item === void 0 ? void 0 : item.quantity) || 0;
};
var getItemSku$2 = function (item) {
    var _a;
    return ((_a = item === null || item === void 0 ? void 0 : item.productVariant) === null || _a === void 0 ? void 0 : _a.sku) || '';
};
var getTotals$1 = function (cart) {
    return {
        total: createPrice(cart === null || cart === void 0 ? void 0 : cart.totalWithTax),
        subtotal: createPrice(cart === null || cart === void 0 ? void 0 : cart.subTotalWithTax)
    };
};
var getTotalItems$3 = function (cart) {
    return (cart === null || cart === void 0 ? void 0 : cart.totalQuantity) || 0;
};
var getDiscounts = function (cart) {
    var _a;
    return (_a = cart === null || cart === void 0 ? void 0 : cart.discounts) === null || _a === void 0 ? void 0 : _a.map(function (discount) { return ({
        id: discount.type,
        name: discount.adjustmentSource,
        value: createPrice(discount.amountWithTax),
        description: discount.description
    }); });
};
// TODO: Develop later filterByAttributeName
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getItemOptions = function (item, filterByAttributeName) {
    var _a, _b;
    var attributes = (_b = (_a = item === null || item === void 0 ? void 0 : item.productVariant) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.map(function (attribute) { return ({
        label: attribute.group.name,
        value: attribute.name
    }); });
    return attributes;
};
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getFormattedPrice$4 = function (price) {
    return '';
};
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getCoupons = function (cart) {
    return [];
};
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getShippingPrice$1 = function (cart) {
    return 0;
};
// Not used in favor of GetItemOptions
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getItemAttributes$1 = function (item, filterByAttributeName) {
    return {
        color: 'red'
    };
};
var cartGetters = {
    getTotals: getTotals$1,
    getShippingPrice: getShippingPrice$1,
    getItems: getItems$3,
    getItemName: getItemName$2,
    getItemImage: getItemImage$1,
    getItemPrice: getItemPrice$2,
    getItemQty: getItemQty$2,
    getItemAttributes: getItemAttributes$1,
    getItemSku: getItemSku$2,
    getFormattedPrice: getFormattedPrice$4,
    getTotalItems: getTotalItems$3,
    getCoupons: getCoupons,
    getDiscounts: getDiscounts,
    getItemOptions: getItemOptions
};

var getNavigation = function (collectionList) {
    var _a;
    // `(category as Collection)` -> When filtering items each item has a type of Node but should have Collection. Probably a bug in Vendure types
    var rootCategories = (_a = collectionList === null || collectionList === void 0 ? void 0 : collectionList.items) === null || _a === void 0 ? void 0 : _a.filter(function (category) { var _a, _b; return ((_b = (_a = category) === null || _a === void 0 ? void 0 : _a.parent) === null || _b === void 0 ? void 0 : _b.name) === ROOT_COLLECTION; });
    var categoryNavigation = rootCategories.map(function (category) {
        var _a, _b;
        return ({
            name: (_a = category) === null || _a === void 0 ? void 0 : _a.name,
            link: (_b = category) === null || _b === void 0 ? void 0 : _b.slug
        });
    });
    return categoryNavigation;
};
var getTotalItems$2 = function (collectionList) {
    return (collectionList === null || collectionList === void 0 ? void 0 : collectionList.totalItems) ? collectionList === null || collectionList === void 0 ? void 0 : collectionList.totalItems : 0;
};
// Not used in favor of facetGetters.getTree
var getTree$1 = function (category) {
    if (!category || !category.id)
        return null;
    return {
        label: '',
        slug: '',
        id: '',
        isCurrent: false,
        items: []
    };
};
var categoryGetters = {
    getTree: getTree$1,
    getNavigation: getNavigation,
    getTotalItems: getTotalItems$2
};

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getShippingMethodId(method) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getShippingMethodName(method) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getShippingMethodDescription(method) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getShippingMethodPrice(method) {
    return 0;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getFormattedPrice$3(price) {
    return '';
}
var checkoutGetters = {
    getShippingMethodId: getShippingMethodId,
    getShippingMethodName: getShippingMethodName,
    getShippingMethodDescription: getShippingMethodDescription,
    getFormattedPrice: getFormattedPrice$3,
    getShippingMethodPrice: getShippingMethodPrice
};

// TODO: Implement search by criteria
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getGrouped = function (searchResult, criteria) {
    var _a, _b;
    if (!((_a = searchResult === null || searchResult === void 0 ? void 0 : searchResult.data) === null || _a === void 0 ? void 0 : _a.facets))
        return [];
    var facets = (_b = searchResult === null || searchResult === void 0 ? void 0 : searchResult.data) === null || _b === void 0 ? void 0 : _b.facets;
    return [{
            id: '1',
            label: 'Attributes',
            count: null,
            options: facets === null || facets === void 0 ? void 0 : facets.map(function (facet) { return ({
                type: 'attribute',
                id: facet.facetValue.id,
                attrName: facet.facetValue.name,
                value: facet.facetValue.code,
                selected: false,
                count: facet.count
            }); })
        }];
};
var getSortOptions = function (searchResult) {
    var _a;
    // TODO: Fix this with custom type/interface. In Vendure `sort: SearchResultSortParameter` while in VSF Core `sort: string`
    var sortName = searchResult.input.sort.price;
    var options = [
        { type: 'sort', id: 'NAME_ASC', value: 'Name from A to Z', count: null },
        { type: 'sort', id: 'NAME_DESC', value: 'Name from Z to A', count: null },
        { type: 'sort', id: 'PRICE_ASC', value: 'Price from low to high', count: null },
        { type: 'sort', id: 'PRICE_DESC', value: 'Price from high to low', count: null }
    ].map(function (o) { return (__assign(__assign({}, o), { selected: o.id === sortName })); });
    var selected = (_a = options.find(function (o) { return o.id === sortName; })) === null || _a === void 0 ? void 0 : _a.id;
    return {
        options: options,
        selected: selected
    };
};
var getProducts = function (searchResult) {
    var _a, _b;
    return ((_b = (_a = searchResult === null || searchResult === void 0 ? void 0 : searchResult.data) === null || _a === void 0 ? void 0 : _a.products) === null || _b === void 0 ? void 0 : _b.length) && searchResult.data.products.map(function (product) { return ({
        _id: product.productId,
        _variantId: product.productVariantId,
        _description: product.description,
        _categoriesRef: product.collectionIds,
        name: product.productName,
        sku: product.sku,
        images: [product.productAsset.preview],
        price: {
            original: product.price.min,
            current: product.priceWithTax.min
        },
        slug: product.slug
    }); });
};
var getPagination = function (searchResult) {
    var _a, _b, _c, _d, _e, _f;
    if (!((_a = searchResult.data) === null || _a === void 0 ? void 0 : _a.total)) {
        return {
            totalPages: 1,
            totalItems: 1,
            itemsPerPage: 1,
            pageOptions: [1],
            currentPage: 1
        };
    }
    return {
        totalPages: Math.ceil(((_b = searchResult === null || searchResult === void 0 ? void 0 : searchResult.data) === null || _b === void 0 ? void 0 : _b.total) / ((_c = searchResult === null || searchResult === void 0 ? void 0 : searchResult.data) === null || _c === void 0 ? void 0 : _c.itemsPerPage)) || 1,
        totalItems: ((_d = searchResult === null || searchResult === void 0 ? void 0 : searchResult.data) === null || _d === void 0 ? void 0 : _d.total) || 0,
        itemsPerPage: (_e = searchResult === null || searchResult === void 0 ? void 0 : searchResult.input) === null || _e === void 0 ? void 0 : _e.take,
        pageOptions: (_f = searchResult === null || searchResult === void 0 ? void 0 : searchResult.data) === null || _f === void 0 ? void 0 : _f.perPageOptions,
        currentPage: 1
    };
};
var getBreadcrumbsFromSlug = function (searchResult, slug) {
    var _a, _b, _c, _d;
    var categoryFromSlug = (_b = (_a = searchResult === null || searchResult === void 0 ? void 0 : searchResult.data) === null || _a === void 0 ? void 0 : _a.categories) === null || _b === void 0 ? void 0 : _b.find(function (category) { return category.collection.slug === slug; });
    var breadcrumbsFromSlug = (_d = (_c = categoryFromSlug === null || categoryFromSlug === void 0 ? void 0 : categoryFromSlug.collection) === null || _c === void 0 ? void 0 : _c.breadcrumbs) === null || _d === void 0 ? void 0 : _d.map(function (breadcrumb) { return ({
        text: (breadcrumb === null || breadcrumb === void 0 ? void 0 : breadcrumb.name) === ROOT_COLLECTION ? 'Home' : breadcrumb === null || breadcrumb === void 0 ? void 0 : breadcrumb.name,
        link: (breadcrumb === null || breadcrumb === void 0 ? void 0 : breadcrumb.slug) === ROOT_COLLECTION ? '/' : breadcrumb === null || breadcrumb === void 0 ? void 0 : breadcrumb.slug
    }); });
    return breadcrumbsFromSlug;
};
var getTree = function (category) {
    if (!category || !category.id)
        return null;
    return {
        label: category.name,
        slug: category.slug,
        id: category.id,
        isCurrent: false,
        items: category.children.map(function (child) { return getTree(child); })
    };
};
var getAgnosticSearchResult = function (searchResultValue) {
    var data = searchResultValue.data, input = searchResultValue.input;
    return {
        data: {
            products: data === null || data === void 0 ? void 0 : data.items,
            categories: data === null || data === void 0 ? void 0 : data.collections,
            facets: data === null || data === void 0 ? void 0 : data.facetValues,
            total: data === null || data === void 0 ? void 0 : data.totalItems,
            perPageOptions: ITEMS_PER_PAGE,
            itemsPerPage: input === null || input === void 0 ? void 0 : input.take
        },
        input: __assign(__assign({}, input), { 
            // In Vendure `sort:{ name: string, price: string }` while in VSF Core `sort: string`
            sort: input.sort })
    };
};
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getAll = function (params, criteria) {
    return [];
};
// Not used in favor of getBreadcrumbsBySlug
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getBreadcrumbs$1 = function (params) {
    return [];
};
// Not used in favor of getTree
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getCategoryTree = function (params) {
    return {
        label: '',
        slug: '',
        items: null,
        isCurrent: false,
        count: 0
    };
};
var facetGetters = {
    getSortOptions: getSortOptions,
    getGrouped: getGrouped,
    getAll: getAll,
    getProducts: getProducts,
    getCategoryTree: getCategoryTree,
    getBreadcrumbs: getBreadcrumbs$1,
    getPagination: getPagination,
    getBreadcrumbsFromSlug: getBreadcrumbsFromSlug,
    getTree: getTree,
    getAgnosticSearchResult: getAgnosticSearchResult
};

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getDate(order) {
    return (order === null || order === void 0 ? void 0 : order.updatedAt) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getId$3(order) {
    return (order === null || order === void 0 ? void 0 : order.id) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getCode(order) {
    return (order === null || order === void 0 ? void 0 : order.code) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getStatus(order) {
    return (order === null || order === void 0 ? void 0 : order.state) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getPrice$1(order) {
    return createPrice(order === null || order === void 0 ? void 0 : order.total);
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItems$2(order) {
    return (order === null || order === void 0 ? void 0 : order.lines) || [];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemSku$1(item) {
    var _a;
    return ((_a = item === null || item === void 0 ? void 0 : item.productVariant) === null || _a === void 0 ? void 0 : _a.sku) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemName$1(item) {
    var _a;
    return ((_a = item === null || item === void 0 ? void 0 : item.productVariant) === null || _a === void 0 ? void 0 : _a.name) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemQty$1(item) {
    return (item === null || item === void 0 ? void 0 : item.quantity) || 0;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemPrice$1(item) {
    return createPrice(item === null || item === void 0 ? void 0 : item.unitPriceWithTax) || 0;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getFormattedPrice$2(price) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getOrdersTotal(orders) {
    return 0;
}
function getTotalItems$1(order) {
    return (order === null || order === void 0 ? void 0 : order.totalItems) || 0;
}
var orderGetters = {
    getDate: getDate,
    getId: getId$3,
    getCode: getCode,
    getStatus: getStatus,
    getPrice: getPrice$1,
    getItems: getItems$2,
    getItemSku: getItemSku$1,
    getItemName: getItemName$1,
    getItemQty: getItemQty$1,
    getItemPrice: getItemPrice$1,
    getFormattedPrice: getFormattedPrice$2,
    getOrdersTotal: getOrdersTotal,
    getTotalItems: getTotalItems$1
};

var getInstance = function () {
    var vm = compositionApi.getCurrentInstance();
    return vm === null || vm === void 0 ? void 0 : vm.$root;
};
var getName = function (product) {
    return (product === null || product === void 0 ? void 0 : product.name) || (product === null || product === void 0 ? void 0 : product.productName) || '';
};
var getSlug = function (product) {
    return (product === null || product === void 0 ? void 0 : product.slug) || '';
};
var getPrice = function (product) {
    var _a, _b, _c;
    return {
        regular: createPrice(((_a = product === null || product === void 0 ? void 0 : product.price) === null || _a === void 0 ? void 0 : _a.current) || ((_b = product === null || product === void 0 ? void 0 : product.priceWithTax) === null || _b === void 0 ? void 0 : _b.value)),
        special: createPrice((_c = product === null || product === void 0 ? void 0 : product.price) === null || _c === void 0 ? void 0 : _c.original)
    };
};
var getGallery = function (product) {
    var _a;
    if (!((_a = product === null || product === void 0 ? void 0 : product.images) === null || _a === void 0 ? void 0 : _a.length))
        return [];
    return product === null || product === void 0 ? void 0 : product.images.map(function (image) { return ({
        small: image,
        normal: image,
        big: image
    }); });
};
var getCoverImage = function (product) {
    var _a, _b;
    return ((_a = product === null || product === void 0 ? void 0 : product.images) === null || _a === void 0 ? void 0 : _a[0]) || ((_b = product === null || product === void 0 ? void 0 : product.productAsset) === null || _b === void 0 ? void 0 : _b.preview) || '';
};
// TODO: Implement filter by attribute functionality
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getOptions = function (product, filters) {
    var _a;
    var mappedOptions = (_a = product === null || product === void 0 ? void 0 : product.optionGroups) === null || _a === void 0 ? void 0 : _a.map(function (optionGroup) {
        var options = optionGroup === null || optionGroup === void 0 ? void 0 : optionGroup.options.map(function (option) { return ({
            id: option === null || option === void 0 ? void 0 : option.id,
            value: option === null || option === void 0 ? void 0 : option.code,
            label: option === null || option === void 0 ? void 0 : option.name
        }); });
        return {
            id: optionGroup === null || optionGroup === void 0 ? void 0 : optionGroup.id,
            value: optionGroup === null || optionGroup === void 0 ? void 0 : optionGroup.code,
            label: optionGroup === null || optionGroup === void 0 ? void 0 : optionGroup.name,
            options: options
        };
    });
    return mappedOptions;
};
var getDescription = function (product) {
    return (product === null || product === void 0 ? void 0 : product._description) || '';
};
var getCategoryIds = function (product) {
    return (product === null || product === void 0 ? void 0 : product._categoriesRef) || [];
};
var getId$2 = function (product) {
    return (product === null || product === void 0 ? void 0 : product._id) || (product === null || product === void 0 ? void 0 : product.productId) || '';
};
var getSku = function (product) {
    return (product === null || product === void 0 ? void 0 : product.sku) || '';
};
var getCategoryNames = function (product) {
    var _a, _b;
    if (!((_a = product.collections) === null || _a === void 0 ? void 0 : _a.length))
        return [];
    return (_b = product === null || product === void 0 ? void 0 : product.collections) === null || _b === void 0 ? void 0 : _b.map(function (collection) { return collection === null || collection === void 0 ? void 0 : collection.name; });
};
var getByFilters = function (product, filters) {
    var variants = product.variants, collections = product.collections, featuredAsset = product.featuredAsset, assets = product.assets, masterVariant = __rest(product, ["variants", "collections", "featuredAsset", "assets"]);
    if (!(variants === null || variants === void 0 ? void 0 : variants.length))
        return [];
    var imagesSet = new Set();
    if (featuredAsset) {
        imagesSet.add(featuredAsset.preview);
    }
    assets.forEach(function (asset) { return imagesSet.add(asset.preview); });
    var productVariants = variants.map(function (variant) { return ({
        _id: variant === null || variant === void 0 ? void 0 : variant.id,
        _description: masterVariant === null || masterVariant === void 0 ? void 0 : masterVariant.description,
        _categoriesRef: collections === null || collections === void 0 ? void 0 : collections.map(function (collection) { return collection.id; }),
        name: variant === null || variant === void 0 ? void 0 : variant.name,
        sku: variant === null || variant === void 0 ? void 0 : variant.sku,
        slug: masterVariant === null || masterVariant === void 0 ? void 0 : masterVariant.slug,
        collections: collections === null || collections === void 0 ? void 0 : collections.map(function (collection) { return ({
            id: collection.id,
            name: collection.name,
            breadcrumbs: collection.breadcrumbs
        }); }),
        images: __spreadArray([], Array.from(imagesSet)),
        price: {
            original: variant === null || variant === void 0 ? void 0 : variant.price,
            current: variant === null || variant === void 0 ? void 0 : variant.priceWithTax
        }
    }); });
    if (filters === null || filters === void 0 ? void 0 : filters.master) {
        return productVariants[0];
    }
    if (filters === null || filters === void 0 ? void 0 : filters.id) {
        return productVariants.find(function (variant) { return variant._id === (filters === null || filters === void 0 ? void 0 : filters.id); });
    }
    return productVariants;
};
// Not used in favor of getByFilters
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getFiltered = function (products, filters) {
    return [];
};
// Not used in favor of getOptions
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getAttributes = function (products, filterByAttributeName) {
    return {
        id: '1',
        name: '1',
        code: '1',
        options: 'options'
    };
};
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getFormattedPrice$1 = function (price) {
    return '';
};
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getTotalReviews$1 = function (product) {
    return 0;
};
// eslint-disable-next-line @typescript-eslint/no-unused-vars
var getAverageRating$1 = function (product) {
    return 0;
};
var getBreadcrumbs = function (product) {
    var _a, _b, _c, _d, _e;
    if (!((_a = product.collections) === null || _a === void 0 ? void 0 : _a.length))
        return [];
    var collection = (_b = product === null || product === void 0 ? void 0 : product.collections) === null || _b === void 0 ? void 0 : _b.slice(-1);
    var instance = getInstance();
    var getRouteByName = function (name) { var _a, _b, _c; return (_c = (_b = (_a = instance === null || instance === void 0 ? void 0 : instance.$router) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.routes) === null || _c === void 0 ? void 0 : _c.find(function (route) { return (route === null || route === void 0 ? void 0 : route.name) === name; }); };
    var homeRouteConfig = getRouteByName('home');
    var categoryRouteConfig = getRouteByName('category');
    // separate the path by slugs to use the segment before the first slug
    var categorySegments = (_c = categoryRouteConfig === null || categoryRouteConfig === void 0 ? void 0 : categoryRouteConfig.path) === null || _c === void 0 ? void 0 : _c.split(':');
    var breadcrumbs = (_e = (_d = collection[0]) === null || _d === void 0 ? void 0 : _d.breadcrumbs) === null || _e === void 0 ? void 0 : _e.map(function (breadcrumb) { return ({
        text: (breadcrumb === null || breadcrumb === void 0 ? void 0 : breadcrumb.name) === ROOT_COLLECTION ? 'Home' : breadcrumb === null || breadcrumb === void 0 ? void 0 : breadcrumb.name,
        link: (breadcrumb === null || breadcrumb === void 0 ? void 0 : breadcrumb.slug) === ROOT_COLLECTION ? (homeRouteConfig === null || homeRouteConfig === void 0 ? void 0 : homeRouteConfig.path) || '/' : ((categorySegments && categorySegments[0]) || '/c/') + (breadcrumb === null || breadcrumb === void 0 ? void 0 : breadcrumb.slug)
    }); });
    breadcrumbs.push({
        text: product === null || product === void 0 ? void 0 : product.name,
        link: product === null || product === void 0 ? void 0 : product.slug
    });
    return breadcrumbs;
};
var productGetters = {
    getName: getName,
    getSlug: getSlug,
    getPrice: getPrice,
    getGallery: getGallery,
    getCoverImage: getCoverImage,
    getFiltered: getFiltered,
    getAttributes: getAttributes,
    getDescription: getDescription,
    getCategoryIds: getCategoryIds,
    getId: getId$2,
    getFormattedPrice: getFormattedPrice$1,
    getTotalReviews: getTotalReviews$1,
    getAverageRating: getAverageRating$1,
    getSku: getSku,
    getCategoryNames: getCategoryNames,
    getByFilters: getByFilters,
    getOptions: getOptions,
    getBreadcrumbs: getBreadcrumbs
};

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItems$1(review) {
    return [];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getReviewId(item) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getReviewAuthor(item) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getReviewMessage(item) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getReviewRating(item) {
    return 0;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getReviewDate(item) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getTotalReviews(review) {
    return 0;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getAverageRating(review) {
    return 0;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getRatesCount(review) {
    return [];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getReviewsPage(review) {
    return 0;
}
var reviewGetters = {
    getItems: getItems$1,
    getReviewId: getReviewId,
    getReviewAuthor: getReviewAuthor,
    getReviewMessage: getReviewMessage,
    getReviewRating: getReviewRating,
    getReviewDate: getReviewDate,
    getTotalReviews: getTotalReviews,
    getAverageRating: getAverageRating,
    getRatesCount: getRatesCount,
    getReviewsPage: getReviewsPage
};

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getAddresses$1(billing, criteria) {
    return billing;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getDefault$1(billing) {
    return billing === null || billing === void 0 ? void 0 : billing.find(function (address) { return address === null || address === void 0 ? void 0 : address.defaultBillingAddress; });
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getTotal$1(billing) {
    return billing === null || billing === void 0 ? void 0 : billing.length;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getPostCode$1(address) {
    return address === null || address === void 0 ? void 0 : address.postalCode;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getStreetName$1(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.streetLine1) === null || _a === void 0 ? void 0 : _a.split(' ')[0];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getStreetNumber$1(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.streetLine1) === null || _a === void 0 ? void 0 : _a.split(' ')[1];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getCity$1(address) {
    return address === null || address === void 0 ? void 0 : address.city;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getFirstName$2(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.fullName) === null || _a === void 0 ? void 0 : _a.split(' ')[0];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getLastName$2(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.fullName) === null || _a === void 0 ? void 0 : _a.split(' ')[1];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getCountry$1(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.country) === null || _a === void 0 ? void 0 : _a.name;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getPhone$1(address) {
    return address === null || address === void 0 ? void 0 : address.phoneNumber;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getEmail$1(address) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getProvince$1(address) {
    return address === null || address === void 0 ? void 0 : address.province;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getCompanyName$1(address) {
    return address === null || address === void 0 ? void 0 : address.company;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getTaxNumber$1(address) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getId$1(address) {
    return address === null || address === void 0 ? void 0 : address.id;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getApartmentNumber$1(address) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function isDefault$1(address) {
    return address === null || address === void 0 ? void 0 : address.defaultShippingAddress;
}
var userBillingGetters = {
    getAddresses: getAddresses$1,
    getDefault: getDefault$1,
    getTotal: getTotal$1,
    getPostCode: getPostCode$1,
    getStreetName: getStreetName$1,
    getStreetNumber: getStreetNumber$1,
    getCity: getCity$1,
    getFirstName: getFirstName$2,
    getLastName: getLastName$2,
    getCountry: getCountry$1,
    getPhone: getPhone$1,
    getEmail: getEmail$1,
    getProvince: getProvince$1,
    getCompanyName: getCompanyName$1,
    getTaxNumber: getTaxNumber$1,
    getId: getId$1,
    getApartmentNumber: getApartmentNumber$1,
    isDefault: isDefault$1
};

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getFirstName$1(user) {
    return (user === null || user === void 0 ? void 0 : user.firstName) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getLastName$1(user) {
    return (user === null || user === void 0 ? void 0 : user.lastName) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getFullName(user) {
    return (user === null || user === void 0 ? void 0 : user.firstName) + " " + (user === null || user === void 0 ? void 0 : user.lastName) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getEmailAddress(user) {
    return (user === null || user === void 0 ? void 0 : user.emailAddress) || '';
}
var userGetters = {
    getFirstName: getFirstName$1,
    getLastName: getLastName$1,
    getFullName: getFullName,
    getEmailAddress: getEmailAddress
};

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getAddresses(shipping, criteria) {
    return shipping;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getDefault(shipping) {
    return shipping === null || shipping === void 0 ? void 0 : shipping.find(function (address) { return address === null || address === void 0 ? void 0 : address.defaultShippingAddress; });
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getTotal(shipping) {
    return shipping === null || shipping === void 0 ? void 0 : shipping.length;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getPostCode(address) {
    return address === null || address === void 0 ? void 0 : address.postalCode;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getStreetName(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.streetLine1) === null || _a === void 0 ? void 0 : _a.split(' ')[0];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getStreetNumber(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.streetLine1) === null || _a === void 0 ? void 0 : _a.split(' ')[1];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getCity(address) {
    return address === null || address === void 0 ? void 0 : address.city;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getFirstName(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.fullName) === null || _a === void 0 ? void 0 : _a.split(' ')[0];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getLastName(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.fullName) === null || _a === void 0 ? void 0 : _a.split(' ')[1];
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getCountry(address) {
    var _a;
    return (_a = address === null || address === void 0 ? void 0 : address.country) === null || _a === void 0 ? void 0 : _a.name;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getPhone(address) {
    return address === null || address === void 0 ? void 0 : address.phoneNumber;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getEmail(address) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getProvince(address) {
    return address === null || address === void 0 ? void 0 : address.province;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getCompanyName(address) {
    return address === null || address === void 0 ? void 0 : address.company;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getTaxNumber(address) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getId(address) {
    return address === null || address === void 0 ? void 0 : address.id;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getApartmentNumber(address) {
    return '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function isDefault(address) {
    return address === null || address === void 0 ? void 0 : address.defaultShippingAddress;
}
var userShippingGetters = {
    getAddresses: getAddresses,
    getDefault: getDefault,
    getTotal: getTotal,
    getPostCode: getPostCode,
    getStreetName: getStreetName,
    getStreetNumber: getStreetNumber,
    getCity: getCity,
    getFirstName: getFirstName,
    getLastName: getLastName,
    getCountry: getCountry,
    getPhone: getPhone,
    getEmail: getEmail,
    getProvince: getProvince,
    getCompanyName: getCompanyName,
    getTaxNumber: getTaxNumber,
    getId: getId,
    getApartmentNumber: getApartmentNumber,
    isDefault: isDefault
};

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItems(wishlist) {
    if (process.client) {
        var wishlist_1 = JSON.parse(localStorage.getItem('wishlist'));
        return wishlist_1;
    }
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getTotals(wishlist) {
    return process.client
        ? wishlist === null || wishlist === void 0 ? void 0 : wishlist.reduce(function (acc, curr) {
            var _a, _b;
            return ({
                // eslint-disable-next-line @typescript-eslint/restrict-plus-operands
                total: (acc === null || acc === void 0 ? void 0 : acc.total) + ((_a = getItemPrice(curr)) === null || _a === void 0 ? void 0 : _a.special),
                // eslint-disable-next-line @typescript-eslint/restrict-plus-operands
                subtotal: (acc === null || acc === void 0 ? void 0 : acc.subtotal) + ((_b = getItemPrice(curr)) === null || _b === void 0 ? void 0 : _b.regular)
            });
        }, ({ total: 0, subtotal: 0 }))
        : { total: 0, subtotal: 0 };
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemName(item) {
    return (item === null || item === void 0 ? void 0 : item.name) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemImage(item) {
    return (item === null || item === void 0 ? void 0 : item.images[0]) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemPrice(item) {
    var _a, _b;
    return {
        regular: createPrice((_a = item === null || item === void 0 ? void 0 : item.price) === null || _a === void 0 ? void 0 : _a.current),
        special: createPrice((_b = item === null || item === void 0 ? void 0 : item.price) === null || _b === void 0 ? void 0 : _b.original)
    };
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemQty(item) {
    return 1;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemAttributes(item, filters) {
    return { '': '' };
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getItemSku(item) {
    return (item === null || item === void 0 ? void 0 : item.sku) || '';
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getShippingPrice(wishlist) {
    return 0;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getTotalItems(wishlist) {
    return wishlist === null || wishlist === void 0 ? void 0 : wishlist.length;
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function getFormattedPrice(price) {
    return '';
}
var wishlistGetters = {
    getItems: getItems,
    getTotals: getTotals,
    getItemName: getItemName,
    getItemImage: getItemImage,
    getItemPrice: getItemPrice,
    getItemQty: getItemQty,
    getItemAttributes: getItemAttributes,
    getShippingPrice: getShippingPrice,
    getItemSku: getItemSku,
    getTotalItems: getTotalItems,
    getFormattedPrice: getFormattedPrice
};

// The getter is not used in Vendure implementation
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
var getResetPasswordToken = function (result) { return result === null || result === void 0 ? void 0 : result.resetPasswordResult; };
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
var isPasswordChanged = function (result) { var _a, _b; return Boolean(((_b = (_a = result === null || result === void 0 ? void 0 : result.setNewPasswordResult) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.resetPassword).id); };
var forgotPasswordGetters = {
    getResetPasswordToken: getResetPasswordToken,
    isPasswordChanged: isPasswordChanged
};
var forgotPasswordGetters$1 = forgotPasswordGetters;

exports.cartGetters = cartGetters;
exports.categoryGetters = categoryGetters;
exports.checkoutGetters = checkoutGetters;
exports.facetGetters = facetGetters;
exports.forgotPasswordGetters = forgotPasswordGetters$1;
exports.orderGetters = orderGetters;
exports.productGetters = productGetters;
exports.reviewGetters = reviewGetters;
exports.useBilling = useBilling;
exports.useCart = useCart;
exports.useCategory = useCategory;
exports.useContent = useContent;
exports.useFacet = useFacet;
exports.useForgotPassword = useForgotPassword;
exports.useMakeOrder = useMakeOrder;
exports.usePayment = usePayment;
exports.useProduct = useProduct;
exports.useRelatedProducts = useRelatedProducts;
exports.useReview = useReview;
exports.useShipping = useShipping;
exports.useShippingProvider = useShippingProvider;
exports.useUser = useUser;
exports.useUserBilling = useUserBilling;
exports.useUserOrder = useUserOrder;
exports.useUserShipping = useUserShipping;
exports.useWishlist = useWishlist;
exports.userBillingGetters = userBillingGetters;
exports.userGetters = userGetters;
exports.userShippingGetters = userShippingGetters;
exports.wishlistGetters = wishlistGetters;
//# sourceMappingURL=index.cjs.js.map
